@@ -6,11 +6,21 @@ from loguru import logger
 
 from . import prioritization
 from . import utils
-from .core import get_next_murcko_fragments, get_all_murcko_fragments, get_murcko_scaffold
+from . import vis
+
+from .core import (
+    get_next_murcko_fragments,
+    get_all_murcko_fragments,
+    get_murcko_scaffold,
+    get_ring_toplogy_scaffold,
+    get_ring_connectivity_scaffold,
+)
+
 from .network import ScaffoldNetwork, HierS
 from .tree import ScaffoldTree, tree_frags_from_mol
 
-__version__ = '1.0.2'
+__version__ = '1.1.0'
+
 
 __all__ = [
     '__version__',
@@ -21,6 +31,8 @@ __all__ = [
     'get_next_murcko_fragments',
     'get_all_murcko_fragments',
     'get_murcko_scaffold',
+    'get_ring_toplogy_scaffold',
+    'get_ring_connectivity_scaffold',
 ]
 
 logger.disable(__name__)
